# template name attributes
%define templatename ubuntu
%define templatever 18.04
%define templatearch x86_64

# Human-readable attributes
%define fullname Ubuntu %templatever
%define fulltemplatearch (for AMD64/Intel EM64T)

# template dirs
%define templatedir /vz/template/%templatename/%templatever/%templatearch/config
%define ostemplatedir %templatedir/os/default

# vzpkgenv related
%define package_manager dpkgx64
%define package_manager_pkg vzpkgenvdebx64 >= 7.0.0

# Files lists
%define files_lst() \
find %1 -type d -printf '%%%dir %%%attr(%m,root,root) %p\\n' | sed "s,%buildroot,,g" >> %2\
find %1 -type f -printf '%%%config %%%attr(%m,root,root) %p\\n' | sed "s,%buildroot,,g" >> %2\
%nil

# Sources list
%define sources_lst() \
%((cd %_sourcedir;\
s=1;\
for tmpl in %*; do\
sources=$tmpl"_*";\
for file in $sources; do\
echo Source$s: $file;\
s=$((s+1))\
done;\
done))\
%nil

# Obsoletes list
%define obsoletes_lst() \
%((for tmpl in %*; do\
[ $tmpl = os ] && continue;\
if [ "${tmpl#os_}" != "$tmpl" ]; then\
echo "Provides: %templatename-%templatever-%templatearch-${tmpl#os_}-ez = %version-%release";\
else\
echo "Obsoletes: $tmpl-%templatename-%templatever-%templatearch-ez < 7.0.0";\
echo "Provides: $tmpl-%templatename-%templatever-%templatearch-ez = %version-%release";\
fi;
done))\
%nil

# Templates list - packages file should be always present in any template!
%define templates_list() %((cd %_sourcedir; for f in *_packages; do echo -n "${f%_*} "; done))

Summary: %fullname %fulltemplatearch Template set
Name: %templatename-%templatever-%templatearch-ez
Group: Virtuozzo/Templates
License: GPL
Version: 8.0.0
Release: 1%{?dist}
BuildRoot: %_tmppath/%name-root
BuildArch: noarch
Requires: %package_manager_pkg

# template source files
%sources_lst %templates_list

# obsoletes
%obsoletes_lst %templates_list

%description
%fullname %fulltemplatearch packaged as a Virtuozzo Template set.

%install
installfile() {
	local sourcename=%_sourcedir/${1}_$4
	local mode=$2
	local dir=$3
	local name=$4

	[ ! -f $sourcename ] && return

	install -m $mode $sourcename $dir/$name
}

rm -f files.lst
for tmpl in %templates_list; do
	if [ $tmpl = "os" ]; then
		dir=%buildroot/%ostemplatedir
		mkdir -p $dir

		# Os template only files

		# Text
		echo "%fullname %fulltemplatearch Virtuozzo Template" > $dir/description
		echo "%fullname %fulltemplatearch Virtuozzo Template" > $dir/summary

		# Package manager
		echo "%package_manager" > $dir/package_manager

		# Disable upgrade
		touch $dir/upgradable_versions

		# Pkgman environment
		installfile $tmpl 0644 $dir environment

		# vzctl-related
		installfile $tmpl 0644 $dir distribution

		# Kernel virtualization
		installfile $tmpl 0644 $dir osrelease

		# Os template cache scripts
		installfile $tmpl 0755 $dir pre-cache
		installfile $tmpl 0755 $dir post-cache
		installfile $tmpl 0755 $dir ct2vm
		installfile $tmpl 0755 $dir mid-pre-install
		installfile $tmpl 0755 $dir mid-post-install
		installfile $tmpl 0755 $dir pre-upgrade
		installfile $tmpl 0755 $dir post-upgrade

		# Additional packages
		installfile $tmpl 0644 $dir packages_0
		installfile $tmpl 0644 $dir packages_1
	elif [ "${tmpl#os_}" != "$tmpl"  ]; then
		dir=%buildroot/%templatedir/os/${tmpl#os_}
		mkdir -p $dir

		# Text
		echo "%fullname ${tmpl#os_} %fulltemplatearch Virtuozzo Template" > $dir/description
		echo "%fullname ${tmpl#os_} %fulltemplatearch Virtuozzo Template" > $dir/summary

		# Os template setname cache scripts
		installfile $tmpl 0755 $dir pre-cache
		installfile $tmpl 0755 $dir post-cache
		installfile $tmpl 0755 $dir mid-pre-install
		installfile $tmpl 0755 $dir mid-post-install
		installfile $tmpl 0755 $dir pre-upgrade
		installfile $tmpl 0755 $dir post-upgrade

		# Additional packages
		installfile $tmpl 0644 $dir packages_0
		installfile $tmpl 0644 $dir packages_1
	else
		dir=%buildroot/%templatedir/app/$tmpl/default
		mkdir -p $dir

		# App templates only files

		# Text
		echo "$tmpl for %fullname %fulltemplatearch Virtuozzo Template" > $dir/description
		echo "$tmpl for %fullname %fulltemplatearch Virtuozzo Template" > $dir/summary
	fi

	# Common things

	# Installation sources
	installfile $tmpl 0644 $dir mirrorlist
	installfile $tmpl 0644 $dir repositories

	# Packages
	installfile $tmpl 0644 $dir packages

	# Scripts
	installfile $tmpl 0755 $dir pre-install
	installfile $tmpl 0755 $dir pre-install-hn
	installfile $tmpl 0755 $dir post-install
	installfile $tmpl 0755 $dir post-install-hn

	# Versioning
	echo "%release" > $dir/release
	echo "%version" > $dir/version
	%files_lst $dir files.lst
done

%files -f files.lst

%changelog
* Mon Aug 24 2020 Alexander Stefanov <astefanov@virtuozzo.com> 7.0.0-18
- add puppet template
- resolve #PSBM-83653 #OVZ-7013

* Thu Jul  5 2018 Konstantin Volkov <wolf@virtuozzo.com> 7.0.0-17
- Drop minimal os template, see #PSBM-86430

* Wed Jul  4 2018 Konstantin Volkov <wolf@virtuozzo.com> 7.0.0-16
- Drop debug post-install output
- Permit root login through ssh

* Mon Jul  2 2018 Konstantin Volkov <wolf@virtuozzo.com> 7.0.0-15
- Install openjre 8 with tomcat implicitly, see #PSBM-86211

* Fri Jun 15 2018 Konstantin Volkov <wolf@virtuozzo.com> 7.0.0-14
- Force mariadb-client installation instead of mysql-client
  with wordpress app template, see #PSBM-85855

* Sat Jun 9 2018 Konstantin Volkov <wolf@virtuozzo.com> 7.0.0-13
- Install openjre and openjdk version 8 for tomcat, see #PSBM-85743

* Fri Jun 8 2018 Konstantin Volkov <wolf@virtuozzo.com> 7.0.0-12
- Use 11 jre and jsdk version in templates, see #PSBM-85666

* Thu Jun 7 2018 Konstantin Volkov <wolf@virtuozzo.com> 7.0.0-11
- Switch php to 7.2, see #PSBM-85401

* Wed Jun 6 2018 Konstantin Volkov <wolf@virtuozzo.com> 7.0.0-10
- Drop dhclient-called resolved script, see #PSBM-85592

* Fri Jun 1 2018 Alexander Stefanov <astefanov@virtuozzo.com> 7.0.0-9
- fix postgresql template #PSBM-85365

* Wed May 23 2018 Alexander Stefanov <astefanov@virtuozzo.com> 7.0.0-7
- fix repo path
- fix naming, according to ubuntu image 18.04 is bionic beaver

* Wed Apr 12 2018 Alexander Stefanov <astefanov@virtuozzo.com> 7.0.0-6
- improve list of devel packages #PSBM-83423

* Wed Apr 11 2018 Alexander Stefanov <astefanov@virtuozzo.com> 7.0.0-5
- remove ttf-freefont and replcae it with fonts-ubuntu ttf-ubuntu-font-family

* Fri Mar 30 2018 Alexander Stefanov <astefanov@virtuozzo.com> 7.0.0-2
- new ubuntu 18.04 template
